@@ -2,7 +2,7 @@ from functools import partial
 from typing import (Optional,
                     Sequence)
 
-from bentley_ottmann.planar import edges_intersect
+from bentley_ottmann.planar import contour_self_intersects
 from clipping.planar import (complete_intersect_multisegments,
                              complete_intersect_segment_with_multisegment,
                              subtract_multisegment_from_segment,
@@ -15,10 +15,9 @@ from clipping.planar import (complete_intersect_multisegments,
 from ground.base import Context
 from ground.hints import Scalar
 from locus import segmental
-from orient.planar import (contour_in_contour,
-                           multisegment_in_contour,
-                           point_in_contour,
-                           segment_in_contour)
+from orient.planar import (multisegment_in_multisegment,
+                           point_in_multisegment,
+                           segment_in_multisegment)
 from reprit.base import generate_repr
 from sect.decomposition import Graph
 
@@ -69,7 +68,7 @@ class Contour(Indexable[Coordinate], Linear[Coordinate]):
         context = self._context
         self._locate = partial(_locate_point, self,
                                context=context)
-        self._segments = segments = context.contour_edges(self)
+        self._segments = segments = context.contour_segments(self)
         self._point_nearest_segment, self._segment_nearest_segment = (
             partial(to_point_nearest_segment, context, segments),
             partial(to_segment_nearest_segment, context, segments))
@@ -522,11 +521,8 @@ class Contour(Indexable[Coordinate], Linear[Coordinate]):
                        else
                        (non_negative_min(self._distance_to_segment(segment)
                                          for segment in other.segments)
-                        if isinstance(other, Multisegment)
-                        else (non_negative_min(self._distance_to_segment(edge)
-                                               for edge in other.segments)
-                              if isinstance(other, Contour)
-                              else other.distance_to(self))))))
+                        if isinstance(other, Linear)
+                        else other.distance_to(self)))))
 
     def index(self) -> None:
         """
@@ -588,13 +584,11 @@ class Contour(Indexable[Coordinate], Linear[Coordinate]):
         """
         return (relate_multipoint_to_linear_compound(other, self)
                 if isinstance(other, Multipoint)
-                else (segment_in_contour(other, self)
+                else (segment_in_multisegment(other, self)
                       if isinstance(other, Segment)
-                      else (multisegment_in_contour(other, self)
-                            if isinstance(other, Multisegment)
-                            else (contour_in_contour(other, self)
-                                  if isinstance(other, Contour)
-                                  else other.relate(self).complement))))
+                      else (multisegment_in_multisegment(other, self)
+                            if isinstance(other, Linear)
+                            else other.relate(self).complement)))
 
     def reverse(self) -> 'Contour[Coordinate]':
         """
@@ -777,7 +771,8 @@ class Contour(Indexable[Coordinate], Linear[Coordinate]):
                for index in range(vertices_count)):
             raise ValueError('Consecutive vertices triplets '
                              'should not be on the same line.')
-        if edges_intersect(self):
+        if contour_self_intersects(self,
+                                   context=self._context):
             raise ValueError('Contour should not be self-intersecting.')
 
     def _distance_to_point(self, other: Point[Coordinate]) -> Scalar:
@@ -799,6 +794,6 @@ def _locate_point(contour: Contour[Coordinate],
                   point: Point[Coordinate],
                   context: Context) -> Location:
     return (Location.BOUNDARY
-            if point_in_contour(point, contour,
-                                context=context)
+            if point_in_multisegment(point, contour,
+                                     context=context)
             else Location.EXTERIOR)
